# coding: utf-8
lib = File.expand_path('../lib', __FILE__)
$LOAD_PATH.unshift(lib) unless $LOAD_PATH.include?(lib)
require 'primitive_wrapper/version'

Gem::Specification.new do |spec|
  spec.name          = "primitive_wrapper"
  spec.version       = PrimitiveWrapper::VERSION
  spec.authors       = ["Bryan Colvin"]
  spec.email         = ["bryan@bdlsys.com"]

  spec.summary       = %q{Thin wrapper for primitive literals}
  spec.description   = %q{This gem creates a thin shell to encapsulate primitive literal types such as integers, floats and symbols.
There are a family of wrappers which mimic the behavior of what they contain.
Primitive types have several drawbacks: no constructor to call, can't create instance variables, and can't create singleton methods.
There is some utility in wrapping a primitive type. You can simulate a call by reference for example.
You can also simulate mutability, and pointers.
Some wrappers are dedicated to holding a single type while others may hold a family of types such as the `Number` wrapper.
What is interesting to note is Number objects do not derive from `Numeric`, but instead derive from `Value` (the wrapper base class);
but at the same time, `Number` objects mimic the methods of `Fixnum`, `Complex`, `Float`, etc.
Many of the wrappers can be used in an expression without having to call an access method.
There are also new types: `Bool` which wraps `true,false` and `Property` which wraps `Hash` types.
The `Property` object auto-methodizes the key names of the Hash.
Also `Fraction` supports mixed fractions.}

  spec.license       = "MIT"

  spec.files         = `git ls-files -z`.split("\x0").reject { |f| f.match(%r{^(test|spec|features)/}) }
  spec.bindir        = "exe"
  spec.executables   = spec.files.grep(%r{^exe/}) { |f| File.basename(f) }
  spec.require_paths = ["lib"]
  
  spec.required_ruby_version = '>= 2.2.0'
  
  spec.add_runtime_dependency 'blockify', '~> 0.2', '>= 0.2.0'
  spec.add_runtime_dependency 'yieldhelper', '~> 0.1', '>= 0.1.0'
  spec.add_runtime_dependency 'pred', '~> 0.1', '>= 0.1.2'

  spec.add_development_dependency "bundler", "~> 1.11"
  spec.add_development_dependency "rake", "~> 10.0"
  spec.add_development_dependency "rspec", "~> 3.0"
  spec.add_development_dependency 'byebug', '~> 5.0', '>= 5.0.0'  
end
